﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using ColorCode;
using SelectPdf;

namespace SelectPdf.Samples
{
    public partial class PdfTemplates : Form
    {
        private void BtnCreatePdf_Click(object sender, EventArgs e)
        {
            Cursor = Cursors.WaitCursor;
            string file = "Document.pdf";

            try
            {
                // create a new pdf document
                PdfDocument doc = new PdfDocument();

                // create a new pdf font
                PdfFont font = doc.AddFont(PdfStandardFont.Helvetica);
                font.Size = 24;

                // add a new page to the document
                PdfPage page = doc.AddPage();

                // create a new text element and add it to the page
                PdfTextElement text = new PdfTextElement(0, 0, Helper.SomeLongText(), font);
                page.Add(text);

                // get image path
                string imgFile = AppDomain.CurrentDomain.BaseDirectory + "/../../files/logo.png";

                // add a template containing an image
                // the image should repeat on all pdf pages automatically
                PdfTemplate template1 = doc.AddTemplate(new RectangleF(100, 0, 400, 150));
                PdfImageElement img1 = new PdfImageElement(0, 0, imgFile);
                template1.Add(img1);

                // add another template containing an image behind the existing page elements
                // (under the text) the image should repeat on all pdf pages automatically
                PdfTemplate template2 = doc.AddTemplate(new RectangleF(100, 200, 400, 150));
                template2.Background = true;
                PdfImageElement img2 = new PdfImageElement(0, 0, imgFile);
                template2.Add(img2);

                // save pdf document
                doc.Save(file);

                // close pdf document
                doc.Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(String.Format("Error: {0}", ex.Message),
                    "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            finally
            {
                Cursor = Cursors.Arrow;
            }

            // open generated pdf
            try
            {
                System.Diagnostics.Process.Start(file);
            }
            catch
            {
                MessageBox.Show("Could not open generated pdf document",
                    "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        public PdfTemplates()
        {
            InitializeComponent();

            try
            {
                // display highlighted sample code
                string code = File.ReadAllText(AppDomain.CurrentDomain.BaseDirectory +
                    "/../../" + "PdfTemplates.cs");
                WBSampleCode.DocumentText = new CodeColorizer().Colorize(code, Languages.CSharp);
            }
            catch
            {
                WBSampleCode.DocumentText = "Sample code not available";
            }
        }

    }
}
