Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Linq
Imports System.Text
Imports System.Threading.Tasks
Imports System.Windows.Forms
Imports System.IO
Imports ColorCode
Imports SelectPdf

Namespace SelectPdf.Samples
    Partial Public Class PdfConverterViewerPreferences
        Inherits Form

        Private Sub BtnCreatePdf_Click(sender As Object, e As EventArgs) _
            Handles BtnCreatePdf.Click
            Cursor = Cursors.WaitCursor
            Dim file As String = "Document.pdf"

            Try
                ' read parameters from the webpage
                Dim url As String = TxtUrl.Text

                Dim page_layout As String = DdlPageLayout.SelectedItem.ToString()
                Dim pageLayout As PdfViewerPageLayout = DirectCast( _
                    [Enum].Parse(GetType(PdfViewerPageLayout), _
                                 page_layout, True), PdfViewerPageLayout)

                Dim page_mode As String = DdlPageMode.SelectedItem.ToString()
                Dim pageMode As PdfViewerPageMode = DirectCast( _
                    [Enum].Parse(GetType(PdfViewerPageMode), _
                                 page_mode, True), PdfViewerPageMode)

                Dim centerWindow As Boolean = ChkCenterWindow.Checked
                Dim displayDocTitle As Boolean = ChkDisplayDocTitle.Checked
                Dim fitWindow As Boolean = ChkFitWindow.Checked
                Dim hideMenuBar As Boolean = ChkHideMenuBar.Checked
                Dim hideToolbar As Boolean = ChkHideToolbar.Checked
                Dim hideWindowUI As Boolean = ChkHideWindowUI.Checked

                ' instantiate a html to pdf converter object
                Dim converter As New HtmlToPdf()

                ' set converter options
                converter.Options.ViewerPreferences.CenterWindow = centerWindow
                converter.Options.ViewerPreferences.DisplayDocTitle = displayDocTitle
                converter.Options.ViewerPreferences.FitWindow = fitWindow
                converter.Options.ViewerPreferences.HideMenuBar = hideMenuBar
                converter.Options.ViewerPreferences.HideToolbar = hideToolbar
                converter.Options.ViewerPreferences.HideWindowUI = hideWindowUI

                converter.Options.ViewerPreferences.PageLayout = pageLayout
                converter.Options.ViewerPreferences.PageMode = pageMode
                converter.Options.ViewerPreferences.NonFullScreenPageMode = _
                    PdfViewerFullScreenExitMode.UseNone

                ' create a new pdf document converting an url
                Dim doc As PdfDocument = converter.ConvertUrl(url)

                ' save pdf document
                doc.Save(file)

                ' close pdf document
                doc.Close()
            Catch ex As Exception
                MessageBox.Show([String].Format("Error: {0}", ex.Message), "Error", _
                                MessageBoxButtons.OK, MessageBoxIcon.[Error])
                Return
            Finally
                Cursor = Cursors.Arrow
            End Try

            ' open generated pdf
            Try
                System.Diagnostics.Process.Start(file)
            Catch
                MessageBox.Show("Could not open generated pdf document", "Error", _
                                MessageBoxButtons.OK, MessageBoxIcon.[Error])
            End Try
        End Sub

        Public Sub New()
            InitializeComponent()

            DdlPageLayout.SelectedIndex = DdlPageLayout.Items.IndexOf("OneColumn")
            DdlPageMode.SelectedIndex = DdlPageMode.Items.IndexOf("UseNone")

            Try
                ' display highlighted sample code
                Dim code As String = File.ReadAllText(AppDomain.CurrentDomain.BaseDirectory + _
                                "/../../" + "PdfConverterViewerPreferences.vb")
                WBSampleCode.DocumentText = New CodeColorizer().Colorize(code, Languages.VbDotNet)
            Catch
                WBSampleCode.DocumentText = "Sample code not available"
            End Try
        End Sub

    End Class
End Namespace
